@@ -112,77 +112,77 @@ static AmpNodeInfo AmpNodeInformations[] = {
 	N_("Shared Library"),
 	"application/x-sharedlib"},
 	AM_TOKEN__LTLIBRARIES,
-	"_LTLIBRARIES",
+	"LTLIBRARIES",
 	"lib"},
 	
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_PRIMARY |  ANJUTA_PROJECT_STATICLIB,
 	N_("Static Library"),
 	"application/x-archive"},
 	AM_TOKEN__LIBRARIES,
-	"_LIBRARIES",
+	"LIBRARIES",
 	"lib"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_PRIMARY | ANJUTA_PROJECT_PROGRAM | ANJUTA_PROJECT_EXECUTABLE,
 	N_("Program"),
 	"application/x-executable"},
 	AM_TOKEN__PROGRAMS,
-	"_PROGRAMS",
+	"PROGRAMS",
 	"bin"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_PYTHON,
 	N_("Python Module"),
 	"application/x-python"},
 	AM_TOKEN__PYTHON,
-	"_PYTHON",
+	"PYTHON",
 	"python"},
 	
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_JAVA,
 	N_("Java Module"),
 	"application/x-java"},
 	AM_TOKEN__JAVA,
-	"_JAVA",
+	"JAVA",
 	"java"},
 	
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_LISP,
 	N_("Lisp Module"),
 	"text/plain"},
 	AM_TOKEN__LISP,
-	"_LISP",
+	"LISP",
 	"lisp"},
 	
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_HEADER,
 	N_("Header Files"),
 	"text/x-chdr"},
 	AM_TOKEN__HEADERS,
-	"_HEADERS",
+	"HEADERS",
 	"include"},
 	
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_MAN,
 	N_("Man Documentation"),
 	"text/x-troff-man"},
 	AM_TOKEN__MANS,
-	"_MANS",
+	"MANS",
 	"man"},
 
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_INFO,
 	N_("Info Documentation"),
 	"application/x-tex-info"},
 	AM_TOKEN__TEXINFOS,
-	"_TEXINFOS",
+	"TEXINFOS",
 	"info"},
 	
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_DATA,
 	N_("Miscellaneous Data"),
 	"application/octet-stream"},
 	AM_TOKEN__DATA,
-	"_DATA",
+	"DATA",
 	"data"},
 	
 	{{ANJUTA_PROJECT_TARGET | ANJUTA_PROJECT_SCRIPT,
 	N_("Script"),
 	"text/x-shellscript"},
 	AM_TOKEN__SCRIPTS,
-	"_SCRIPTS",
+	"SCRIPTS",
 	"bin"},
 
 	{{ANJUTA_PROJECT_MODULE,
@@ -322,7 +322,7 @@ canonicalize_automake_variable (const gchar *name)
 	return canon_name;
 }
 
-static gboolean
+gboolean
 split_automake_variable (gchar *name, gint *flags, gchar **module, gchar **primary)
 {
 	GRegex *regex;
@@ -720,7 +720,7 @@ amp_project_load_module (AmpProject *project, AnjutaToken *module_token)
 		/* Module name */
 		arg = anjuta_token_first_item (module_token);
 		value = anjuta_token_evaluate (arg);
-		module = amp_module_node_new (value, NULL);
+		module = amp_module_node_new (value);
 		amp_module_node_add_token (module, module_token);
 		anjuta_project_node_append (ANJUTA_PROJECT_NODE (project), ANJUTA_PROJECT_NODE (module));
 
@@ -762,7 +762,7 @@ amp_project_load_module (AmpProject *project, AnjutaToken *module_token)
 			}
 			else
 			{
-				package = amp_package_node_new (value, NULL);
+				package = amp_package_node_new (value);
 				amp_package_node_add_token (package, item);
 				anjuta_project_node_append (ANJUTA_PROJECT_NODE (module), ANJUTA_PROJECT_NODE (package));
 				anjuta_project_node_set_state (ANJUTA_PROJECT_NODE (package), ANJUTA_PROJECT_INCOMPLETE);
@@ -859,7 +859,7 @@ project_load_target (AmpProject *project, AnjutaProjectNode *parent, AnjutaToken
 		}
 
 		/* Create target */
-		target = amp_target_node_new (value, info->base.type, install, flags, NULL);
+		target = amp_target_node_new_valid (value, info->base.type, install, flags, NULL);
 		if (target != NULL)
 		{
 			amp_target_node_add_token (target, ANJUTA_TOKEN_ARGUMENT, arg);
@@ -906,6 +906,7 @@ project_load_target (AmpProject *project, AnjutaProjectNode *parent, AnjutaToken
 					anjuta_project_node_append (ANJUTA_PROJECT_NODE (target), child);
 					g_object_unref (child);
 				}
+				amp_target_changed (target);
 				g_free (orig_key);
 				amp_target_node_free (orphan);
 			}
@@ -950,10 +951,10 @@ project_load_target (AmpProject *project, AnjutaProjectNode *parent, AnjutaToken
 }
 
 static AnjutaToken*
-project_load_sources (AmpProject *project, AnjutaProjectNode *parent, AnjutaToken *variable, GHashTable *orphan_properties)
+project_load_sources (AmpProject *project, AnjutaProjectNode *group, AnjutaToken *variable, GHashTable *orphan_properties)
 {
 	AnjutaToken *arg;
-	GFile *parent_file = g_object_ref (anjuta_project_node_get_file (ANJUTA_PROJECT_NODE (parent)));
+	GFile *group_file = g_object_ref (anjuta_project_node_get_file (ANJUTA_PROJECT_NODE (group)));
 	gchar *target_id = NULL;
 
 	target_id = anjuta_token_evaluate (anjuta_token_first_word (variable));
@@ -973,7 +974,7 @@ project_load_sources (AmpProject *project, AnjutaProjectNode *parent, AnjutaToke
 		
 		find = target_id;
 		DEBUG_PRINT ("search for canonical %s", target_id);
-		anjuta_project_node_children_traverse (parent, find_canonical_target, &find);
+		anjuta_project_node_children_traverse (group, find_canonical_target, &find);
 		target = (gchar *)find != target_id ? (AnjutaProjectNode *)find : NULL;
 
 		/* Get orphan buffer if there is no target */
@@ -988,7 +989,7 @@ project_load_sources (AmpProject *project, AnjutaProjectNode *parent, AnjutaToke
 			}
 			else
 			{
-				target = ANJUTA_PROJECT_NODE (amp_target_node_new ("dummy", 0, NULL, 0, NULL));
+				target = ANJUTA_PROJECT_NODE (amp_target_node_new ("dummy", 0, NULL, 0));
 			}
 			g_hash_table_insert (orphan_properties, target_id, target);
 		}
@@ -1002,14 +1003,54 @@ project_load_sources (AmpProject *project, AnjutaProjectNode *parent, AnjutaToke
 		{
 			gchar *value;
 			AnjutaProjectNode *source;
+			AnjutaProjectNode *parent = target;
 			GFile *src_file;
+			GFileInfo* file_info;
 		
 			value = anjuta_token_evaluate (arg);
 			if (value == NULL) continue;
 
+			src_file = g_file_get_child (group_file, value);
+			if (project->lang_manager != NULL)
+			{
+				file_info = g_file_query_info (src_file,
+					                                          G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+				    	                                      G_FILE_QUERY_INFO_NONE,
+		    		    	                                  NULL,
+		        		    	                              NULL);
+				if (file_info)
+				{
+					gint id = ianjuta_language_get_from_mime_type (project->lang_manager,
+			    		                                           g_file_info_get_content_type (file_info),
+			        		                                       NULL);
+					if (id > 0)
+					{
+						const gchar *obj_ext = ianjuta_language_get_make_target (project->lang_manager, id, NULL);
+						if (obj_ext != NULL)
+						{
+							/* Create object node */
+							gchar *object_name;
+							gchar *ext;
+							GFile *obj_file;
+							AnjutaProjectNode *object;
+
+							ext = strrchr (value, '.');
+							if ((ext != NULL) && (ext != value)) *ext = '\0';
+							object_name = g_strconcat (value, obj_ext, NULL);
+							obj_file = g_file_get_child (group_file, object_name);
+							g_free (object_name);
+							object = amp_node_new_valid (group, ANJUTA_PROJECT_OBJECT | ANJUTA_PROJECT_PROJECT, obj_file, NULL, NULL); 
+							g_object_unref (obj_file);
+							anjuta_project_node_append (parent, object);
+							parent = object;
+						}
+					}
+					g_object_unref (file_info);
+				}
+			}
+			
 			/* Create source */
-			src_file = g_file_get_child (parent_file, value);
-			source = amp_node_new (parent, ANJUTA_PROJECT_SOURCE | ANJUTA_PROJECT_PROJECT, src_file, NULL, NULL);
+			source = amp_node_new_valid (group, ANJUTA_PROJECT_SOURCE | ANJUTA_PROJECT_PROJECT, src_file, NULL, NULL);
 			g_object_unref (src_file);
 			if (source != NULL)
 			{
@@ -1017,14 +1058,15 @@ project_load_sources (AmpProject *project, AnjutaProjectNode *parent, AnjutaToke
 	
 				DEBUG_PRINT ("add target child %p", target);
 				/* Add as target child */
-				anjuta_project_node_append (target, source);
+				anjuta_project_node_append (parent, source);
 			}
 
 			g_free (value);
 		}
+		amp_target_changed (target);
 	}
 
-	g_object_unref (parent_file);
+	g_object_unref (group_file);
 
 	return NULL;
 }
@@ -1061,7 +1103,7 @@ project_load_data (AmpProject *project, AnjutaProjectNode *parent, AnjutaToken *
 	if ((gchar *)find == target_id)
 	{
 		/* Create target */
-		target = amp_target_node_new (target_id, info->base.type, install, flags, NULL);
+		target = amp_target_node_new_valid (target_id, info->base.type, install, flags, NULL);
 		if (target != NULL)
 		{
 			anjuta_project_node_append (parent, ANJUTA_PROJECT_NODE (target));
@@ -1091,7 +1133,7 @@ project_load_data (AmpProject *project, AnjutaProjectNode *parent, AnjutaToken *
 
 			/* Create source */
 			src_file = g_file_get_child (parent_file, value);
-			source = amp_node_new (parent, ANJUTA_PROJECT_SOURCE | ANJUTA_PROJECT_PROJECT | data_flags, src_file, NULL, NULL);
+			source = amp_node_new_valid (parent, ANJUTA_PROJECT_SOURCE | ANJUTA_PROJECT_PROJECT | data_flags, src_file, NULL, NULL);
 			g_object_unref (src_file);
 			if (source != NULL)
 			{
@@ -1179,7 +1221,7 @@ project_load_target_properties (AmpProject *project, AnjutaProjectNode *parent,
 			else
 			{
 				/* Create dummy target */
-				parent = ANJUTA_PROJECT_NODE (amp_target_node_new ("dummy", 0, NULL, 0, NULL));
+				parent = ANJUTA_PROJECT_NODE (amp_target_node_new ("dummy", 0, NULL, 0));
 			}
 			g_hash_table_insert (orphan_properties, target_id, parent);
 		}
@@ -1192,6 +1234,7 @@ project_load_target_properties (AmpProject *project, AnjutaProjectNode *parent,
 		/* Add property to target */
 		amp_node_property_add (parent, prop);
 		amp_target_node_add_token (AMP_TARGET_NODE (parent), type, variable);
+		amp_target_changed (AMP_TARGET_NODE (parent));
 	}
 
 	return NULL;
@@ -1265,7 +1308,7 @@ project_load_subdirs (AmpProject *project, AnjutaToken *list, AnjutaProjectNode
 			else
 			{
 				/* Create new group */
-				group = amp_group_node_new (subdir, dist_only, NULL);
+				group = amp_group_node_new_valid (subdir, dist_only, NULL);
 				
 				/* Group can be NULL if the name is not valid */
 				if (group != NULL)
@@ -1524,6 +1567,11 @@ amp_project_duplicate_node (AnjutaProjectNode *old_node)
 		// the value will be overwritten with the new node empty value.
 		amp_package_node_add_token (AMP_PACKAGE_NODE (new_node), amp_package_node_get_token (AMP_PACKAGE_NODE (old_node)));
 	}
+	if (anjuta_project_node_get_node_type (old_node) == ANJUTA_PROJECT_ROOT)
+	{
+		// FIXME: It would be better to write a duplicate function to avoid this code
+		((AmpProject *)new_node)->lang_manager = (((AmpProject *)old_node)->lang_manager != NULL) ? g_object_ref (((AmpProject *)old_node)->lang_manager) : NULL;
+	}
 	/* Keep old parent, Needed for source node to find project root node */
 	new_node->parent = old_node->parent;
 
@@ -1603,7 +1651,7 @@ amp_project_load_root (AmpProject *project, GError **error)
 	}
 
 	/* Load all makefiles recursively */
-	group = amp_group_node_new (root_file, FALSE, NULL);
+	group = amp_group_node_new (root_file, FALSE);
 	g_hash_table_insert (project->groups, g_file_get_uri (root_file), group);
 	anjuta_project_node_append (ANJUTA_PROJECT_NODE (project), ANJUTA_PROJECT_NODE (group));
 
@@ -1611,7 +1659,7 @@ amp_project_load_root (AmpProject *project, GError **error)
 	{
 		g_set_error (error, IANJUTA_PROJECT_ERROR, 
 					IANJUTA_PROJECT_ERROR_DOESNT_EXIST,
-			_("Project doesn't exist or invalid path"));
+			_("Project doesn't exist or has an invalid path"));
 
 		return FALSE;
 	}
@@ -1887,7 +1935,7 @@ amp_project_dump (AmpProject *project, AnjutaProjectNode *node)
 
 
 AmpProject *
-amp_project_new (GFile *file, GError **error)
+amp_project_new (GFile *file, IAnjutaLanguage *language, GError **error)
 {
 	AmpProject *project;
 	GFile *new_file;
@@ -1896,6 +1944,8 @@ amp_project_new (GFile *file, GError **error)
 	new_file = g_file_dup (file);
 	amp_root_node_set_file (AMP_ROOT_NODE (project), new_file);
 	g_object_unref (new_file);
+
+	project->lang_manager = (language != NULL) ? g_object_ref (language) : NULL;
 	
 	return project;
 }
@@ -2144,7 +2194,7 @@ amp_set_property_work (PmJob *job)
 	}
 	else if (flags & AM_PROPERTY_IN_MAKEFILE)
 	{
-		if (((AmpProperty *)job->property->native)->suffix != NULL)
+		if (((AnjutaProjectProperty *)job->property->native)->flags & ANJUTA_PROJECT_PROPERTY_READ_WRITE)
 		{
 			amp_project_update_am_property (AMP_PROJECT (job->user_data), job->node, job->property);
 		}
@@ -2228,7 +2278,7 @@ iproject_add_node_before (IAnjutaProject *obj, AnjutaProjectNode *parent, Anjuta
 
 	if (AMP_PROJECT (obj)->queue == NULL) AMP_PROJECT (obj)->queue = pm_command_queue_new ();
 
-	node = amp_node_new (parent, type, file, name, err);
+	node = amp_node_new_valid (parent, type, file, name, err);
 	if (node != NULL)
 	{	
 		add_job = pm_job_new (&amp_add_before_job, node, parent, sibling, ANJUTA_PROJECT_UNKNOWN, NULL, NULL, obj);
@@ -2246,7 +2296,7 @@ iproject_add_node_after (IAnjutaProject *obj, AnjutaProjectNode *parent, AnjutaP
 
 	if (AMP_PROJECT (obj)->queue == NULL) AMP_PROJECT (obj)->queue = pm_command_queue_new ();
 
-	node = amp_node_new (parent, type, file, name, err);
+	node = amp_node_new_valid (parent, type, file, name, err);
 	if (node != NULL)
 	{	
 		add_job = pm_job_new (&amp_add_after_job, node, parent, sibling, ANJUTA_PROJECT_UNKNOWN, NULL, NULL, obj);
@@ -2399,6 +2449,9 @@ amp_project_dispose (GObject *object)
 	if (project->monitor) g_object_unref (project->monitor);
 	project->monitor = NULL;
 
+	if (project->lang_manager) g_object_unref (project->lang_manager);
+	project->lang_manager = NULL;
+	
 	G_OBJECT_CLASS (parent_class)->dispose (object);	
 }
 
