@@ -224,7 +224,7 @@ file_view_row_activated (GtkTreeView* widget, GtkTreePath* sort_path,
 static gboolean
 file_view_key_press_event (GtkWidget* widget, GdkEventKey* event)
 {
-	if (event->keyval == GDK_Return || event->keyval == GDK_KP_Enter)
+	if (event->keyval == GDK_KEY_Return || event->keyval == GDK_KEY_KP_Enter)
 	{
 		AnjutaFileView* view = ANJUTA_FILE_VIEW (widget);
 		AnjutaFileViewPrivate* priv = ANJUTA_FILE_VIEW_GET_PRIVATE (view);
@@ -581,10 +581,6 @@ file_view_init (AnjutaFileView *object)
 		gtk_tree_view_get_selection (GTK_TREE_VIEW (object));
 	g_signal_connect (selection, "changed",
 					  G_CALLBACK (file_view_selection_changed), object);
-	
-	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (object), FALSE);
-	
-	g_object_set (object, "has-tooltip", TRUE, NULL);
 
 	/* DND */
 	gtk_tree_view_enable_model_drag_source (GTK_TREE_VIEW(object),
@@ -707,8 +703,20 @@ file_view_class_init (AnjutaFileViewClass *klass)
 	widget_class->drag_data_get = file_view_drag_data_get;
 }
 
+void 
+file_view_refresh_vcs (AnjutaFileView* view)
+{
+	AnjutaFileViewPrivate* priv = ANJUTA_FILE_VIEW_GET_PRIVATE (view);
+    file_model_update_vcs_status(priv->model);
+}
+
+
 GtkWidget*
 file_view_new (void)
 {
-	return g_object_new (ANJUTA_TYPE_FILE_VIEW, NULL);
+	return g_object_new (ANJUTA_TYPE_FILE_VIEW, 
+	                     "headers-visible", FALSE,
+	                     "has-tooltip", TRUE,
+	                     "enable-search", FALSE,
+	                     NULL);
 }
